@@ -8,21 +8,53 @@ get_hypothesis <- function(
 
     if (is.null(hypothesis)) return(x)
 
+    if (isTRUE(checkmate::check_choice(hypothesis, "meandev"))) {
+        hypothesis <- function(x) {
+            out <- x
+            out$estimate <- out$estimate - mean(out$estimate)
+            out$hypothesis <- "Mean deviation"
+            return(out)
+        }
+    } else if (isTRUE(checkmate::check_choice(hypothesis, "meanotherdev"))) {
+        hypothesis <- function(x) {
+            out <- x
+            s <- sum(out$estimate)
+            m_other <- (s - out$estimate) / (nrow(x) - 1)
+            out$estimate <- out$estimate - m_other
+            out$hypothesis <- "Mean deviation (other)"
+            return(out)
+        }
+    }
+
     if (is.function(hypothesis)) {
+        if (!is.null(draws)) {
+            msg <- "The `hypothesis` argument does not support function for models with draws. You can use `posterior_draws()` to extract draws and manipulate them directly instead."
+            insight::format_error(msg)
+        }
+        if ("rowid" %in% colnames(x) && "rowid" %in% colnames(newdata)) {
+            x <- merge(x, newdata, all.x = TRUE, by = intersect(colnames(x), colnames(newdata)))
+        } else if (isTRUE(nrow(x) == nrow(newdata))) {
+            x <- cbind(x, newdata)
+        }
+
+        attr(x, "variables_datagrid") <- attr(newdata, "variables_datagrid")
+        attr(x, "by") <- if (is.character(by)) by else names(by)
+
         argnames <- names(formals(hypothesis))
-        if (!"x" %in% argnames) stop("The `hypothesis` function must accept an `x` argument.", call. = FALSE)
-        if (any(!argnames %in% c("x", "newdata", "by", "draws", "..."))) {
-            msg <- "The allowable arguments for the `hypothesis` function are: x, newdata`, by, and draws."
-            stop(msg, call. = FALSE)
+        if (!"x" %in% argnames) insight::format_error("The `hypothesis` function must accept an `x` argument.")
+        if (any(!argnames %in% c("x", "draws"))) {
+            msg <- "The allowable arguments for the `hypothesis` function are: `x` and `draws`"
+            insight::format_error(msg)
         }
         args <- list(x = x, newdata = newdata, by = by, draws = draws)
         args <- args[names(args) %in% argnames]
         out <- do.call(hypothesis, args)
+        at <- attr(out, "hypothesis_function_by")
 
         # sanity
-        msg <- "The `hypothesis` argument function must return a data frame with `term` and `estimate` columns."
+        msg <- "The `hypothesis` argument function must return a data frame with `term` (or `hypothesis`) and `estimate` columns."
         if (inherits(out, "data.frame")) {
-            if (!all(c("term", "estimate") %in% colnames(out))) {
+            if (!all(c("term", "estimate") %in% colnames(out)) && !all(c("hypothesis", "estimate") %in% colnames(out))) {
                 insight::format_error(msg)
             }
         } else if (isTRUE(checkmate::check_numeric(out))) {
@@ -34,6 +66,8 @@ get_hypothesis <- function(
         } else {
             insight::format_error(msg)
         }
+
+        attr(out, "hypothesis_function_by") <- at
         return(out)
     }
 
