@@ -38,7 +38,7 @@ get_vcov.default <- function(model,
     if (!isTRUE(checkmate::check_matrix(out$value, min.rows = 1))) {
         out <- myTryCatch(insight::get_varcov(model))
         if (isTRUE(checkmate::check_matrix(out$value, min.rows = 1))) {
-            msg <- "Unable to extract a variance-covariance matrix using this `vcov` argument. Standard errors are computed using the default variance instead. Perhaps the model or argument is not supported by the `sandwich` or `clubSandwich` packages. If you believe that the model is supported by one of these two packages, you can open a feature request on Github."
+            msg <- "Unable to extract a variance-covariance matrix using this `vcov` argument. Standard errors are computed using the default variance instead. Perhaps the model or argument is not supported by the `sandwich` ('HC0', 'HC3', ~clusterid, etc.) or `clubSandwich` ('CR0', etc.) packages. If you believe that the model is supported by one of these two packages, you can open a feature request on Github."
             insight::format_warning(msg)
         }
     }
