@@ -100,12 +100,20 @@ sanity_comparison <- function(comparison) {
 
 sanitize_transform <- function(x) {
     good <- c("exp", "ln")
-    checkmate::assert(
-        checkmate::check_choice(x, choices = good, null.ok = TRUE),
-        checkmate::check_function(x))
+    # issue #1115: sanitize_transform() wraps `transform` into a named list, so the assertion may fail when using `inferences()`
+    if (isTRUE(checkmate::check_list(x, names = "named"))) {
+        checkmate::assert(
+            checkmate::check_choice(x[[1]], choices = good, null.ok = TRUE),
+            checkmate::check_function(x[[1]]))
+        x <- x[[1]]
+    } else {
+        checkmate::assert(
+            checkmate::check_choice(x, choices = good, null.ok = TRUE),
+            checkmate::check_function(x))
+    }
 
     if (is.null(x)) {
-        return(x) 
+        return(x)
     } else if (is.function(x)) {
         out <- list(x)
         names(out) <- deparse(substitute(x))
@@ -116,6 +124,5 @@ sanitize_transform <- function(x) {
     }
 
     return(out)
-
 }
 
